# Changelog

## 1.1.3 (2026-01-12)

Full Changelog: [v1.1.2...v1.1.3](https://github.com/Not-Diamond/not-diamond-python/compare/v1.1.2...v1.1.3)

### Features

* add Slack notification workflow for new pull requests ([97535a3](https://github.com/Not-Diamond/not-diamond-python/commit/97535a3158340c4dce76370718068ebd412e64e9))
* **api:** api update ([616dcaa](https://github.com/Not-Diamond/not-diamond-python/commit/616dcaa965dc5fde8d79dfa2ce01ad14f1d5ab91))
* enhance Slack PR notification to include 'ready for review' status and additional details ([af8afd5](https://github.com/Not-Diamond/not-diamond-python/commit/af8afd5aa9253bac48f0600c06eb649c66a3b2d7))


### Chores

* remove commented-out line for bot notification exclusion in Slack PR workflow ([e0c337e](https://github.com/Not-Diamond/not-diamond-python/commit/e0c337ed9a951826b060204809180d074ca79c88))
* remove condition to exclude bot users from Slack notification in PR workflow ([776b597](https://github.com/Not-Diamond/not-diamond-python/commit/776b597086b06869bca76818eaaaaca4e4940531))

## 1.1.2 (2025-12-19)

Full Changelog: [v1.1.1...v1.1.2](https://github.com/Not-Diamond/not-diamond-python/compare/v1.1.1...v1.1.2)

### Chores

* **internal:** add `--fix` argument to lint script ([448c196](https://github.com/Not-Diamond/not-diamond-python/commit/448c1962fc32893b4cd7ace7d2a1c1b1a8beb479))

## 1.1.1 (2025-12-18)

Full Changelog: [v1.1.0...v1.1.1](https://github.com/Not-Diamond/not-diamond-python/compare/v1.1.0...v1.1.1)

### Bug Fixes

* use async_to_httpx_files in patch method ([edc6ef8](https://github.com/Not-Diamond/not-diamond-python/commit/edc6ef8ed4023637b73f77a60d671118490149ad))


### Chores

* speedup initial import ([6a70606](https://github.com/Not-Diamond/not-diamond-python/commit/6a706065bd55c616c38d10f3fa1c13cd6e32ca99))

## 1.1.0 (2025-12-16)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** api update ([aa449df](https://github.com/Not-Diamond/not-diamond-python/commit/aa449df78f1d0aa8d6714f375cd2075df4456837))
* **api:** api update ([b5cbefd](https://github.com/Not-Diamond/not-diamond-python/commit/b5cbefd0b1ce6ee883e7847510b9f5fd5ad22899))


### Chores

* **api:** changed default client name to NotDiamond ([8599dc8](https://github.com/Not-Diamond/not-diamond-python/commit/8599dc8db216ea164a04f781fd12b9455d00366c))
* **internal:** add missing files argument to base client ([6a2fc27](https://github.com/Not-Diamond/not-diamond-python/commit/6a2fc2744efef181cbf6a413e3e35bda38c79a1a))

## 1.0.1 (2025-12-09)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0...v1.0.1)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([5663881](https://github.com/Not-Diamond/not-diamond-python/commit/566388145d7d3fea2e52158963fc2ad8e8ee45c8))


### Chores

* add missing docstrings ([003db35](https://github.com/Not-Diamond/not-diamond-python/commit/003db35899fda442fd45bdcafe4aeaad09b1dd4d))

## 1.0.0 (2025-12-08)

Full Changelog: [v1.0.0-rc18...v1.0.0](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc18...v1.0.0)

### Features

* **api:** api update ([d35e3bf](https://github.com/Not-Diamond/not-diamond-python/commit/d35e3bf24a62a770d70ccc9627b5136d6ea4e4de))

## 1.0.0-rc18 (2025-12-08)

Full Changelog: [v1.0.0-rc17...v1.0.0-rc18](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc17...v1.0.0-rc18)

### Chores

* **docs:** update README with new prompt adaptation examples and enable prototype mode ([bcaa9e8](https://github.com/Not-Diamond/not-diamond-python/commit/bcaa9e86cc0fe32c3a339d5bf85fed5d24246ef1))

## 1.0.0-rc17 (2025-12-08)

Full Changelog: [v1.0.0-rc16...v1.0.0-rc17](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc16...v1.0.0-rc17)

### Features

* **api:** api update ([80741ad](https://github.com/Not-Diamond/not-diamond-python/commit/80741adc8c0dddc791ffc9b680385baf8beba1a0))
* **api:** api update ([e6cc0b3](https://github.com/Not-Diamond/not-diamond-python/commit/e6cc0b3f0f5fd5a4d8ac2a0b66070a67b0986ec9))
* **api:** api update ([9514729](https://github.com/Not-Diamond/not-diamond-python/commit/9514729f30190892396343daddbc8c6d657edbc8))
* **api:** manual updates ([3de5719](https://github.com/Not-Diamond/not-diamond-python/commit/3de57198fad333e98cb6d32df8a1cb3cecf997dc))


### Bug Fixes

* ensure streams are always closed ([94cd458](https://github.com/Not-Diamond/not-diamond-python/commit/94cd458b5027c72a25b0ea0f9dce70f0f11c738e))


### Chores

* add Python 3.14 classifier and testing ([9acba74](https://github.com/Not-Diamond/not-diamond-python/commit/9acba7453c5da79029dc88dc074a844e8bf025b4))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([578a964](https://github.com/Not-Diamond/not-diamond-python/commit/578a964fd65e2d01aaf61aeedcf1d9c471447aa1))
* **docs:** use environment variables for authentication in code snippets ([4493c72](https://github.com/Not-Diamond/not-diamond-python/commit/4493c723b56c4f402327fca66a47f755b09a5bc3))
* update lockfile ([8b040bc](https://github.com/Not-Diamond/not-diamond-python/commit/8b040bc315c0cf48380efb8578b7a197ef654413))

## 1.0.0-rc16 (2025-11-14)

Full Changelog: [v1.0.0-rc15...v1.0.0-rc16](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc15...v1.0.0-rc16)

### Features

* **api:** manual updates ([f10b3cf](https://github.com/Not-Diamond/not-diamond-python/commit/f10b3cf27f9ce359c020e1a2e1ac8cf66e1f8c35))


### Documentation

* update README to reflect changes in prompt adaptation method names and remove outdated async usage section ([c793b18](https://github.com/Not-Diamond/not-diamond-python/commit/c793b18630bf398ae32bcb2d5adfdf91cc65c8f9))

## 1.0.0-rc15 (2025-11-14)

Full Changelog: [v1.0.0-rc14...v1.0.0-rc15](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc14...v1.0.0-rc15)

### Features

* **api:** api update ([12c16a2](https://github.com/Not-Diamond/not-diamond-python/commit/12c16a218d211c47aaad82ad672f668a27715edf))

## 1.0.0-rc14 (2025-11-14)

Full Changelog: [v1.0.0-rc13...v1.0.0-rc14](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc13...v1.0.0-rc14)

### Features

* **api:** manual updates ([48af7c1](https://github.com/Not-Diamond/not-diamond-python/commit/48af7c13347f7db5ef8e0063c8e5f8363d092d01))

## 1.0.0-rc13 (2025-11-13)

Full Changelog: [v1.0.0-rc12...v1.0.0-rc13](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc12...v1.0.0-rc13)

### Features

* **api:** manual updates ([ae9b855](https://github.com/Not-Diamond/not-diamond-python/commit/ae9b855e1d9ec3dccdd96bd121ac11aba1402981))


### Documentation

* update README to include example of initializing NotDiamond client with API key ([3f3a1e5](https://github.com/Not-Diamond/not-diamond-python/commit/3f3a1e5ca3911eada1a2c0abfa1c2c5d0bf75cbc))
* update README to reflect changes in Prompt Adaptation details and streamline key features section ([71f97f8](https://github.com/Not-Diamond/not-diamond-python/commit/71f97f8348e2fb21af321ac7965d53e3fb88211f))
* update README to remove outdated Prompt Adaptation section and add new examples for intelligent model routing and training a custom router. ([17b08b6](https://github.com/Not-Diamond/not-diamond-python/commit/17b08b65ef604d68e766c0cb16cee70d0cd4d575))

## 1.0.0-rc12 (2025-11-12)

Full Changelog: [v1.0.0-rc11...v1.0.0-rc12](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc11...v1.0.0-rc12)

### Bug Fixes

* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([1417077](https://github.com/Not-Diamond/not-diamond-python/commit/14170771cd8e66d2aab39bd5b866dfd081eb45f0))


### Chores

* **internal:** codegen related update ([b26fdeb](https://github.com/Not-Diamond/not-diamond-python/commit/b26fdeb30acc5c5b4e26ae1d1dd76dbee69ca09b))

## 1.0.0-rc11 (2025-11-11)

Full Changelog: [v1.0.0-rc10...v1.0.0-rc11](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc10...v1.0.0-rc11)

### Features

* **api:** changed name ([a5fbbc6](https://github.com/Not-Diamond/not-diamond-python/commit/a5fbbc6174cd362389bd1e3848f2b870bdf37837))


### Bug Fixes

* compat with Python 3.14 ([566b7bf](https://github.com/Not-Diamond/not-diamond-python/commit/566b7bf3583a41330dc9ada230e343fc852dd7ad))


### Chores

* **package:** drop Python 3.8 support ([8f6e2eb](https://github.com/Not-Diamond/not-diamond-python/commit/8f6e2eb71d0523fa1d7b6bb39c30ffbbc95363cf))

## 1.0.0-rc10 (2025-11-10)

Full Changelog: [v1.0.0-rc9...v1.0.0-rc10](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc9...v1.0.0-rc10)

### Features

* **api:** manual updates ([3b34f4f](https://github.com/Not-Diamond/not-diamond-python/commit/3b34f4fb9f5ed2281a5672179f759f7eccb41dc0))

## 1.0.0-rc9 (2025-11-10)

Full Changelog: [v1.0.0-rc8...v1.0.0-rc9](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc8...v1.0.0-rc9)

### Features

* **api:** manual updates ([50911a0](https://github.com/Not-Diamond/not-diamond-python/commit/50911a023f29a7017ec810e55ee55209c5dbdacc))

## 1.0.0-rc8 (2025-11-10)

Full Changelog: [v1.0.0-rc7...v1.0.0-rc8](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc7...v1.0.0-rc8)

### Features

* **api:** manual updates ([1d846ce](https://github.com/Not-Diamond/not-diamond-python/commit/1d846ce29e4e8688e82bd64d500d3752af77d6de))

## 1.0.0-rc7 (2025-11-07)

Full Changelog: [v1.0.0-rc6...v1.0.0-rc7](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc6...v1.0.0-rc7)

### Features

* **api:** api update ([bdb1ebe](https://github.com/Not-Diamond/not-diamond-python/commit/bdb1ebe855fe24f1c9d93804fea1ef38ae77341d))

## 1.0.0-rc6 (2025-11-06)

Full Changelog: [v1.0.0-rc5...v1.0.0-rc6](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc5...v1.0.0-rc6)

### Features

* **api:** manual updates ([e864113](https://github.com/Not-Diamond/not-diamond-python/commit/e864113c227997b0c04a02cad05b8963fe5a9283))

## 1.0.0-rc5 (2025-11-05)

Full Changelog: [v1.0.0-rc4...v1.0.0-rc5](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc4...v1.0.0-rc5)

### Features

* **api:** manual updates ([0a7ac49](https://github.com/Not-Diamond/not-diamond-python/commit/0a7ac4986879837b1b93bb31c5b7e6d211a55077))


### Chores

* update SDK settings ([227346c](https://github.com/Not-Diamond/not-diamond-python/commit/227346c8e801e2ee7f0f7c376fb55e5aea606232))

## 1.0.0-rc4 (2025-11-05)

Full Changelog: [v1.0.0-rc3...v1.0.0-rc4](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc3...v1.0.0-rc4)

### Features

* **api:** manual updates ([dd9657d](https://github.com/Not-Diamond/not-diamond-python/commit/dd9657df2226d7d46cf99ee8b23eced653155c74))

## 1.0.0-rc3 (2025-11-05)

Full Changelog: [v1.0.0-rc2...v1.0.0-rc3](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc2...v1.0.0-rc3)

### Features

* **api:** api update ([0cdedc2](https://github.com/Not-Diamond/not-diamond-python/commit/0cdedc27ef1bab63e433bdc0717c36cc48d60b55))
* **api:** api update ([f717b91](https://github.com/Not-Diamond/not-diamond-python/commit/f717b91a37cd48a63e9ef9458cef6dd899383f2c))
* **api:** api update ([24340ab](https://github.com/Not-Diamond/not-diamond-python/commit/24340ab121937a85e9c4bbc8b644c62b15f75d89))
* **api:** enable tests ([64ccd03](https://github.com/Not-Diamond/not-diamond-python/commit/64ccd03281ae7b420b44cf64910568e3657f24db))
* **api:** regen docs ([c80dbe1](https://github.com/Not-Diamond/not-diamond-python/commit/c80dbe1994cd73b549995b5e91ac86a62a77f5b7))
* **api:** verify mock tests enabled ([638d79b](https://github.com/Not-Diamond/not-diamond-python/commit/638d79bdd90097d9823d02e3dac8b12ab2849d03))


### Chores

* **internal:** grammar fix (it's -&gt; its) ([6d37a12](https://github.com/Not-Diamond/not-diamond-python/commit/6d37a125457223046183bcc8ee7159ed96b80424))
* update SDK settings ([ba3968b](https://github.com/Not-Diamond/not-diamond-python/commit/ba3968b9ef7b2ec9e7b1b3983a6e2a8b31ccbc37))

## 1.0.0-rc2 (2025-10-31)

Full Changelog: [v1.0.0-rc1...v1.0.0-rc2](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc1...v1.0.0-rc2)

### Features

* **api:** api update ([f4f83bd](https://github.com/Not-Diamond/not-diamond-python/commit/f4f83bd926d4296f883f5db75de90a5db275867a))

## 1.0.0-rc1 (2025-10-31)

Full Changelog: [v0.3.0...v1.0.0-rc1](https://github.com/Not-Diamond/not-diamond-python/compare/v0.3.0...v1.0.0-rc1)

### Features

* **api:** fix modelSelect error ([eb29990](https://github.com/Not-Diamond/not-diamond-python/commit/eb29990fab14468f39368f7f5b0e4ebf019d0841))
* **api:** manual updates ([b905d72](https://github.com/Not-Diamond/not-diamond-python/commit/b905d72ebec4d42373de62865a85f62d4a87c477))
* **api:** manual updates ([d664d8d](https://github.com/Not-Diamond/not-diamond-python/commit/d664d8d20ab802a9aa0150519a3900d386f7b1d9))


### Bug Fixes

* **client:** close streams without requiring full consumption ([c9f7310](https://github.com/Not-Diamond/not-diamond-python/commit/c9f73103e1747f06da439c77b7d5e322c4d09a4e))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([14e720b](https://github.com/Not-Diamond/not-diamond-python/commit/14e720b4d735b9a52d634b1ec24db5bff9c3aa24))
* update SDK settings ([26ae314](https://github.com/Not-Diamond/not-diamond-python/commit/26ae3141eaa1df28dd8b1d1e5d322fb135bee6b9))

## 0.3.0 (2025-10-24)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([d403264](https://github.com/Not-Diamond/not-diamond-python/commit/d4032647605736f1c51d04023d3adb24f448737f))
* **api:** api update ([c7a1198](https://github.com/Not-Diamond/not-diamond-python/commit/c7a1198c1432e833b740f92df9996379f941228f))
* **api:** api update ([9265a0a](https://github.com/Not-Diamond/not-diamond-python/commit/9265a0a3959818b06f157726e68d3c73f7f5d9c9))
* **api:** api update ([880c195](https://github.com/Not-Diamond/not-diamond-python/commit/880c195dc41ac5e500cae9b9a71b0840f97e7556))
* **api:** exclude non sdk endpoints ([fb04bc4](https://github.com/Not-Diamond/not-diamond-python/commit/fb04bc460d7f9f7f191cffcb56868d09fa45edc1))
* **api:** fix missing endpoint ([427d1d3](https://github.com/Not-Diamond/not-diamond-python/commit/427d1d3bdd7be290e66897aa35daba984931e4a4))
* **api:** manual updates ([603c1b7](https://github.com/Not-Diamond/not-diamond-python/commit/603c1b74c64850e1fd8a89e08b1d66d0665188e0))
* **api:** manual updates ([42fb39e](https://github.com/Not-Diamond/not-diamond-python/commit/42fb39e0978aa329f4b5171ff54aaab257558135))
* **api:** report group ([4312188](https://github.com/Not-Diamond/not-diamond-python/commit/43121880104978fa2b88a3ad0e85070a2b322787))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([37d5de2](https://github.com/Not-Diamond/not-diamond-python/commit/37d5de2162ece6024539d9e546dd2679ba5e1882))
* **internal:** detect missing future annotations with ruff ([316a749](https://github.com/Not-Diamond/not-diamond-python/commit/316a7493d166e631eafcc888d377dbe340178b24))

## 0.2.0 (2025-10-09)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([9ee8b3e](https://github.com/Not-Diamond/not-diamond-python/commit/9ee8b3e1220e45b00ce9c9078ab7f54bb1e34e19))

## 0.1.0 (2025-10-09)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([8062369](https://github.com/Not-Diamond/not-diamond-python/commit/80623692c7da0db7c57b7953af3ec9fdc1e0fca2))


### Chores

* update SDK settings ([ecc0dc6](https://github.com/Not-Diamond/not-diamond-python/commit/ecc0dc63a8d98e9d2178f04cebde730257bae353))
